<?php

namespace Drupal\mercury_editor;

use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Provides a service for Mercury Editor context.
 */
class MercuryEditorContextService {

  /**
   * The route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * MercuryEditorContextService constructor.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   */
  public function __construct(RouteMatchInterface $route_match) {
    $this->routeMatch = $route_match;
  }

  /**
   * Whether or not the current route is a Mercury Editor preview.
   *
   * @return bool
   *   TRUE if the current route is a Mercury Editor preview, FALSE otherwise.
   */
  public function isPreview() {
    return $this->routeMatch->getRouteName() == 'mercury_editor.preview'
      || str_ends_with($this->routeMatch->getRouteName(), '.mercury_editor_preview');
  }

  /**
   * Returns the mercury editor preview entity for the route.
   */
  public function getEntity() {
    $route_name = $this->routeMatch->getRouteName();
    if ($route_name == 'mercury_editor.editor') {
      return $this->routeMatch->getParameter('mercury_editor_entity') ?? NULL;
    }
    if (str_ends_with($route_name, '.mercury_editor_preview')) {
      $entity_type = explode('.', $route_name)[1];
      return $this->routeMatch->getParameter($entity_type) ?? NULL;
    }
    return NULL;
  }

}
